@@ -28,7 +28,7 @@ Readonly my $NOT_FOUND      => -1;
 my $uuid_object = Data::UUID->new;
 my $EMPTY       = q{};
 
-our $VERSION = '2.8.1';
+our $VERSION = '2.10.1';
 
 my ( $prog_name, $logger, %callback, $_self );
 
@@ -102,6 +102,7 @@ sub quit {
     if ( defined $_self->{thread} ) {
         $_self->{thread}->join();
         $_self->{thread} = undef;
+        Image::Sane::_exit();    ## no critic (ProtectPrivateSubs)
     }
     return;
 }
@@ -529,7 +530,10 @@ sub _thread_open_device {
     }
 
     # close the handle
-    if ( defined( $self->{device_handle} ) ) { undef $self->{device_handle} }
+    if ( defined( $self->{device_handle} ) ) {
+        undef $self->{device_handle};
+        Image::Sane::_exit();    ## no critic (ProtectPrivateSubs)
+    }
 
     my $status = SANE_STATUS_GOOD;
     try {
