@@ -13,7 +13,7 @@ use English qw( -no_match_vars );    # for $PROCESS_ID
 use Gscan2pdf::Translation '__';     # easier to extract strings with xgettext
 use Locale::Language;
 
-our $VERSION = '2.10.0';
+our $VERSION = '2.10.1';
 my $EMPTY = q{};
 my $COMMA = q{,};
 
@@ -228,7 +228,7 @@ sub hocr {
     $warnings =~ s/^Page[ ][01]\n//xsm;
 
     if ( $name eq 'stdout' ) {
-        return Encode::decode_utf8($out), $warnings;
+        return $out, $warnings;
     }
     return Gscan2pdf::Document::slurp($txt), $warnings;
 }
